@@ -85,7 +85,7 @@ def daemonize():
         
 def main(usage, get_app):
     parser = op.OptionParser(usage=usage, option_list=options(),
-                    version="%prog 0.4")
+                    version="%prog 0.4.1")
     opts, args = parser.parse_args()
     configure_logging(opts)
 
@@ -231,11 +231,17 @@ def run_paster():
             workers = opts.workers
         else:
             workers = int(ctx.local_conf.get('workers', 1))
-
-        host = opts.host or ctx.local_conf.get('host', '127.0.0.1')
-        port = opts.port or int(ctx.local_conf.get('port', 8000))
-        bind = "%s:%s" % (host, port)
-
+     
+        if not opts.bind:
+            host = ctx.local_conf.get('host')
+            port = ctx.local_conf.get('port')
+            if host:
+                if port:
+                    bind = "%s:%s" % (host, port)
+                else:
+                    bind = host
+                opts.bind = bind
+        
         debug = ctx.global_conf.get('debug') == "true"
         if debug:
             # we force to one worker in debug mode.
