@@ -28,7 +28,7 @@ weekdayname = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
 monthname = [None,
              'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
              'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
-             
+
 def get_maxfd():
     maxfd = resource.getrlimit(resource.RLIMIT_NOFILE)[1]
     if (maxfd == resource.RLIM_INFINITY):
@@ -80,7 +80,7 @@ def write(sock, data):
         
 def write_nonblock(sock, data):
     timeout = sock.gettimeout()
-    if sock.gettimeout() > 0.0:
+    if timeout != 0.0:
         try:
             sock.setblocking(0)
             return write(sock, data)
@@ -93,7 +93,7 @@ def writelines(sock, lines):
     for line in list(lines):
         write(sock, line)
 
-def write_error(sock, mesg):
+def write_error(sock, msg):
     html = textwrap.dedent("""\
     <html>
         <head>
@@ -105,7 +105,7 @@ def write_error(sock, mesg):
             <pre>%s</pre>
         </body>
     </html>
-    """) % mesg
+    """) % msg
     http = textwrap.dedent("""\
     HTTP/1.0 500 Internal Server Error\r
     Connection: close\r
@@ -113,7 +113,7 @@ def write_error(sock, mesg):
     Content-Length: %d\r
     \r
     %s
-    """) % (len(http), http)
+    """) % (len(html), html)
     write_nonblock(sock, http)
 
 def normalize_name(name):
